// general.js

// General functions that may be useful for any character sheets made
// in PCProfiler. You may wish to use these function for any d20
// character sheets you make.
// Dependencies: (none)

var __DEBUG__ = false;

function CalculateMod(nAbilityScore)
{
    // Returns the modifier for a supplied ability score.
    // Return value is appended with a "+" sign if the modifier is
    // positive.
    var myNum = parseInt(nAbilityScore);
    if (isNaN(myNum))
        return("--");
    else
    {
        // Calculate the modifier.
        if ((myNum % 2) == 1)
            myNum -= 11;
        else
            myNum -= 10;
        myNum /= 2;
        
        // Append the "+" sign if positive.
        if (myNum > 0)
            myNum = "+" + myNum;
        
        return(myNum);
    }
}

function Add()
{
    // Accepts any number of arguments.
    // Parses seach argument for integers and returns the sum. A zero value
    // is assumed for an argument if parsing fails. If parsing fails on all
    // arguments, a "+0" string is returned.
    var myRetVal = 0;
    for (i = 0; i < arguments.length; i++)
    {
        var myVal = parseInt(arguments[i]);
        if (isNaN(myVal))
            myVal = 0;
        myRetVal += myVal;
    }
    if (myRetVal >= 0)
        myRetVal = "+" + myRetVal;
    return(myRetVal);
}

function Clean(nNum)
{
    // Returns a "clean" number. That is, stripped of any leading "+" sign,
    // or a zero value if nNum can't be evaluated to an integer.
    var myRetVal = parseInt(nNum);
    if (isNaN(myRetVal))
        myRetVal = 0;
    return myRetVal;
}

function FormatNumber(nNum)
{
    // Returns a number with a leading zero of < 10.
    if (nNum < 10)
        return("0" + nNum);
    return nNum;
}