// skills.js

// Various functions used for calculating and presenting the skill info.
// dependencies: general.js

function CalcSkills(strAbility, nMod)
{
    // Scan all skills for key abilities equal to strAbility, and replace
    // matching Ability Modifier inputs with nMod, then recalculate the
    // Skill modifier.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    var myAb = new String(strAbility).toLowerCase();
    for (var i = 1; i < 36; i++)
    {
        var myCurrentAb = new String(document.all["Skill"
            + FormatNumber(i) + "Ab"].value).toLowerCase();
        if (myAb == myCurrentAb)
        {
            document.all["Skill" + FormatNumber(i) + "AbMod"].value = nMod;
            CalcSkill(i);
        }
    }
}

function CalcSkill(nNum)
{
    // Recalculates the total modifier of the skill specified by nNum.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    var inMod = document.all["Skill" + FormatNumber(nNum) +"Mod"];
    var myAbMod = document.all["Skill" + FormatNumber(nNum) + "AbMod"].value;
    var myRank = document.all["Skill" + FormatNumber(nNum) + "Rank"].value;
    var myMiscMod = document.all["Skill" + FormatNumber(nNum) + "MiscMod"].value;
    inMod.value = Add(myAbMod, myRank, myMiscMod);
}

function RecalcTotalRank()
{
    // Tallies the ranks, taking into consideration whether each skill is
    // a cross-class skill.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    var myTotal = 0;
    var nCC;
    for (var i = 1; i < 36; i++)
    {
        document.all["Skill" + FormatNumber(i) + "CC"].checked ?
            nCC = 2 : nCC = 1;
        myTotal += ((Clean(
            document.all["Skill" + FormatNumber(i) + "Rank"].value))
            * nCC);
    }
    //document.all.SkillTotal.value = myTotal;
    document.all.SkillTotal.innerHTML = myTotal;
    window.status = "Recalculated total Skill Points";
}

function GetModifier(strAb)
{
    // Retrieves the proper modifier for the specific ability.
    // Uses the temp modifier if one exists, otherwise returns
    // the normal modifier.
    var myMod;
    switch (strAb)
    {
        case "str":
            if (isNaN(parseInt(document.all.StrTempMod.value)))
                myMod = parseInt(document.all.StrMod.value);
            else
                myMod = parseInt(document.all.StrTempMod.value);
            break;
        case "dex":
            if (isNaN(parseInt(document.all.DexTempMod.value)))
                myMod = parseInt(document.all.DexMod.value);
            else
                myMod = parseInt(document.all.DexTempMod.value);
            break;
        case "con":
            if (isNaN(parseInt(document.all.ConTempMod.value)))
                myMod = parseInt(document.all.ConMod.value);
            else
                myMod = parseInt(document.all.ConTempMod.value);
            break;
        case "int":
            if (isNaN(parseInt(document.all.IntTempMod.value)))
                myMod = parseInt(document.all.IntMod.value);
            else
                myMod = parseInt(document.all.IntTempMod.value);
            break;
        case "wis":
            if (isNaN(parseInt(document.all.WisTempMod.value)))
                myMod = parseInt(document.all.WisMod.value);
            else
                myMod = parseInt(document.all.WisTempMod.value);
            break;
        case "cha":
            if (isNaN(parseInt(document.all.ChaTempMod.value)))
                myMod = parseInt(document.all.ChaMod.value);
            else
                myMod = parseInt(document.all.ChaTempMod.value);
            break;
    }
    if (isNaN(myMod))
        myMod = 0;
    return myMod;
}

function GenerateSkillName(nNum)
{
    // Returns the skill name (entered by user) specified by nNum.
    // If skill is unnamed, returns an "(Unnamed)" string.
    var mySkill = document.all["Skill" + FormatNumber(nNum)].value;
    if (mySkill == "")
        mySkill = "(Unnamed)";
    return mySkill;
}

function OnChangeAb(nNum)
{
    // Copies the ability modifier to the appropriate skill input.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    var myAb = new String(
        document.all["Skill"
        + FormatNumber(nNum) + "Ab"].value).toLowerCase();
    var myMod = GetModifier(myAb);
    
    document.all["Skill" + FormatNumber(nNum) + "AbMod"].value = myMod;
    CalcSkill(nNum);
    
    // Generate status message.
    window.status = "Changed " + GenerateSkillName(nNum) + " skill modifier to reflect new key ability.";
}

function OnChangeAbMod(nNum)
{
    // Calls the functions for when the ability modifier of an ability
    // is changed.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    CalcSkill(nNum);
    
    // Generate status message.
    window.status = "Updated total modifier for " + GenerateSkillName(nNum) + ".";
}

function OnChangeRank(nNum)
{
    // Calls the series of functions when a rank is updated.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    CalcSkill(nNum);
    RecalcTotalRank();
    
    // Generate status message.
    window.status = "Updated total modifier for " + GenerateSkillName(nNum) + ". Retallied total skill points.";
}

function OnChangeMiscMod(nNum)
{
    // Calls the series of functions when the Misc mod for a skill is
    // changed.
    if (document.all.disableAutoCalc != undefined)
        if (document.all.disableAutoCalc.value == 1)
            return;

    CalcSkill(nNum);
    
    // Generate status message.
    window.status = "Updated total modifier for " + GenerateSkillName(nNum) + ".";
}