// Data.js
//
// Definition and implementation of the CData class. This is a map (or hash)
// class that contains members to generate a flattened version of its data,
// or re-create the map from a flat data string.
//
// Note, the pipes chracter (|) is used as a delimiter, and is stripped from
// any of the key or value strings.
//
// Example:
//     var myDataMap =  new CData();
//     myDataMap.SetValue("Hello", "World");
//     myDataMap.SetValue("Name", "MJEggertson");
//     var myFlatData = myDataMap.GenerateDataString();
//     // Set myTestString to what myFlatData should be.
//     var myTestString;
//     myTestString = "Hello|World||Name|MJEggertson";
//     if (myTestString == myFlatData) // True
//         alert("The test string matched the returned value!");

// Class Construction.
function CData()
{
    // Private members.
    var m_map = new ActiveXObject("Scripting.Dictionary");
    
    // Public accessor pointers.
    this.GetValue = GetValue;
    this.SetValue = SetValue;
    this.GenerateDataString = GenerateDataString;
    this.CreateFromDataString = CreateFromDataString;
    
    // Public Accessors
    function GetValue(strName)
    {
        // Returns the value associated with strName, or undefined if strName
        // was not found.
        if (m_map.Exists(strName))
            return m_map.Item(strName);
        return undefined;
    }
    
    function SetValue(strName, strValue)
    {
        // Don't store empty data.
        if (String(strValue).length == 0)
        {
            if (m_map.Exists(strName))
                m_map.Remove(strName);
            return;
        }

        // Strip any offending pipe characters.
        strName = strName.replace("|", "");
        strValue = strValue.replace("|", "");

        // Set the value.
        if (m_map.Exists(strName))
            m_map.Item(strName) = strValue;
        else
            m_map.Add(strName, strValue);
    }
    
    // Public Members.
    function GenerateDataString()
    {
        // Returns a coded string which contains all the data in m_data.
        // Each name/value pair in m_data is seperated with a tab character,
        // and each element is seperated by two tab characters.
        var t = new String();
        var keys = (new VBArray(m_map.Keys())).toArray();
        for (var i = 0; i < keys.length; i++)
            t += keys[i] + "|" + m_map.Item(keys[i]) + "||";
        return t;
    }
    
    function CreateFromDataString(str)
    {
        // Delete any existing elements.
        m_map.RemoveAll();
        
        // Decode the data string and populate the map.
        var pairs = str.split("||");
        for (var i = 0; i < (pairs.length - 1); i++)
        {
            var d = pairs[i].split("|", 2);
            SetValue(d[0], d[1]);
            document.all[d[0]].value = d[1];
        }
    }
    
    return this;
}
